@@ -239,7 +239,7 @@ setMethod(f="bib",
 #' #My_traits<-tr8(species_list=c("Abies alba"),download_traits=c("le_area","h_max","h_min"))
 #' }
 #' @export tr8
-tr8<-function(species_list,download_list=NULL,gui_config=FALSE,synonyms=FALSE){
+tr8<-function(species_list,download_list=NULL,gui_config=FALSE,synonyms=FALSE,catminat_alternatives=FALSE){
 
     ## if(tryCatch(nsl("www.cran.r-project.org"), error =function(e){return(FALSE)},warning=function(w){return(FALSE)})==FALSE){
     ##     stop("You need a working internet connection to use tr8()")
@@ -281,7 +281,7 @@ tr8<-function(species_list,download_list=NULL,gui_config=FALSE,synonyms=FALSE){
             ## run the gui
             traits_list<-tr8_config()
         }else{
-            for(db in c("BiolFlor","LEDA","Ecoflora","Pignatti","AMF","Catminat","BROT","PLANTS","EFlora_Cal")){
+            for(db in c("BiolFlor","LEDA","Ecoflora","Pignatti","AMF","Catminat","BROT","PLANTS","EFlora_Cal","Imkerbond")){
                                         #db<-temp_dframe$db[temp_dframe$short_code==i]
                 data_db<-temp_dframe[temp_dframe$db==db,]
                 if(sum(data_db$short_code%in%download_list)>0){
@@ -292,7 +292,7 @@ tr8<-function(species_list,download_list=NULL,gui_config=FALSE,synonyms=FALSE){
         }
         if(synonyms==TRUE){
             
-            check_names<-tnrs(species_list)
+            check_names<-tnrs(species_list,verbose=FALSE)
             check_names<-check_names[,c("submittedname","acceptedname","matchedname")]
             
             reference_names<-lapply(species_list,function(x){
@@ -320,7 +320,7 @@ tr8<-function(species_list,download_list=NULL,gui_config=FALSE,synonyms=FALSE){
             }
         }
         eco_traits<-ecoflora(species_list,TRAITS=traits_list$Ecoflora,rest=rest)
-
+        
         ## check if an already downloaded version of the LEDA database
         ## exists and, if so, use it otherwise download a copy, but only
         ## if at least one LEDA trait is needed
@@ -345,7 +345,7 @@ tr8<-function(species_list,download_list=NULL,gui_config=FALSE,synonyms=FALSE){
         leda_traits<-leda(species_list,TRAITS=traits_list$LEDA,rearranged=rearranged)
         
         ## retrieve data from BiolFlor
-        biolflor_traits<-biolflor(species_list,TRAITS=traits_list$BiolFlor,rest=rest)
+        biolflor_traits<-biolflor(species_list,TRAITS=traits_list$BiolFlor,rest=rest,directory=directory)
         
         ## retrieve data from Pignatti
         pignatti_traits<-pignatti_f(species_list,TRAITS=traits_list$Pignatti)
@@ -402,7 +402,10 @@ tr8<-function(species_list,download_list=NULL,gui_config=FALSE,synonyms=FALSE){
         amf_MycoFlor<-retrieve_MycoFlor(species_list,TRAITS=TRAIT_MYC,rest=rest,data_myco=MycoFlor)
 
 
+        ## Imkerbond
 
+
+        Imkerbond_traits <- imkerbond_get(species_list,TRAITS=traits_list$Imkerbond)
         
         ## check if an already downloaded version of the Catminat database
         ## exists and, if so, use it otherwise download a copy, but only
@@ -416,7 +419,7 @@ tr8<-function(species_list,download_list=NULL,gui_config=FALSE,synonyms=FALSE){
             }else{catminat_df<-NULL}
         }
         ##        leda_traits<-leda(species_list,TRAITS=traits_list$LEDA,rearranged=rearranged)
-        catminat_traits<-catminat(species_list,TRAITS=traits_list$Catminat,catminat_df)
+        catminat_traits<-catminat(species_list,TRAITS=traits_list$Catminat,catminat_df,similar=catminat_alternatives)
         
         ## check if an already downloaded version of the BROT database
         ## exists and, if so, use it otherwise download a copy, but only
@@ -454,7 +457,7 @@ tr8<-function(species_list,download_list=NULL,gui_config=FALSE,synonyms=FALSE){
         tr8_traits<-data.frame(species_list,row.names=species_list)
         bibliography=list()
         potential_issues<-c()
-        for(i in c(eco_traits,biolflor_traits,leda_traits,pignatti_traits,it_flowering,amf_traits,amf_MycoFlor,catminat_traits,brot_traits,PLANT_traits,efloracal_traits)){
+        for(i in c(eco_traits,biolflor_traits,leda_traits,pignatti_traits,it_flowering,amf_traits,amf_MycoFlor,catminat_traits,brot_traits,PLANT_traits,efloracal_traits,Imkerbond_traits)){
             ## merge the dataframes only if they contain data
             if(!is.null(i@results))
             {
@@ -476,7 +479,7 @@ tr8<-function(species_list,download_list=NULL,gui_config=FALSE,synonyms=FALSE){
         ## names(tr8_traits)<-names_columns
         ## tr8_traits<-as.data.frame(tr8_traits[,names_columns],row.names = row_names)
         tr8_traits<-tr8_traits[,!(names(tr8_traits)%in%c("Row.names","species_list")),drop=FALSE]
-
+        
         obj<-new("Tr8")
         ##    obj@double_names<-unique(c(eco_traits@double_names,leda_traits@double_names))
         ##    obj@not_valid<-intersect(intersect(eco_traits@not_valid,leda_traits@not_valid),pignatti_traits@not_valid)
@@ -484,13 +487,13 @@ tr8<-function(species_list,download_list=NULL,gui_config=FALSE,synonyms=FALSE){
         ## biolflor_clean is not needed any more
         ## tr8_traits<-biolflor_clean(tr8_traits)
         tr8_traits<-column_conversion(tr8_traits)
-
+        
         
         if(synonyms==TRUE){
             
             reference_names<-ldply(lapply(reference_names,ldply))
             names(reference_names)<-c("original_names","synonyms")
-            tr8_traits<-merge(reference_names,tr8_traits,by.x="synonyms",by.y=0)
+            tr8_traits<-merge(reference_names,tr8_traits,by.x="synonyms",by.y=0,all=T)
             ## in this case, where synonyms are required, then
             ## row names is left with "numbers" since many strange coincidences may
             ## happen (eg. two different species may have been found under the
